==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebHeadSelectorTemplateDetailsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebHeadSelectorTemplateDetailsDescription } from "./WebHeadSelectorTemplateDetailsDescription";
/**
 * @hidden
 */
export let WebHeadSelectorTemplateDetailsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebHeadSelectorTemplateDetailsDescriptionMetadata extends Base {
        static b(a) {
            if (WebHeadSelectorTemplateDetailsDescriptionMetadata.a == null) {
                WebHeadSelectorTemplateDetailsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebHeadSelectorTemplateDetailsDescriptionMetadata.c(WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
            }
            if (a.j(WebHeadSelectorTemplateDetailsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:HeadSelectorTemplateDetails");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("SelectedCount", "Number:double");
            a.item("TotalCount", "Number:double");
        }
        static d(a) {
            WebHeadSelectorTemplateDetailsDescriptionMetadata.b(a);
            a.aa("WebHeadSelectorTemplateDetails", () => new WebHeadSelectorTemplateDetailsDescription());
            a.z("WebHeadSelectorTemplateDetails", WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
        }
    }
    WebHeadSelectorTemplateDetailsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebHeadSelectorTemplateDetailsDescriptionMetadata, 'WebHeadSelectorTemplateDetailsDescriptionMetadata');
    WebHeadSelectorTemplateDetailsDescriptionMetadata.a = null;
    return WebHeadSelectorTemplateDetailsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebHeadSelectorTemplateDetailsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebHeadSelectorTemplateDetailsDescription } from "./WebHeadSelectorTemplateDetailsDescription";
/**
 * @hidden
 */
export let WebHeadSelectorTemplateDetailsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebHeadSelectorTemplateDetailsDescriptionMetadata extends Base {
        static b(a) {
            if (WebHeadSelectorTemplateDetailsDescriptionMetadata.a == null) {
                WebHeadSelectorTemplateDetailsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebHeadSelectorTemplateDetailsDescriptionMetadata.c(WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
            }
            if (a.k(WebHeadSelectorTemplateDetailsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:HeadSelectorTemplateDetails");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("SelectedCount", "Number:double");
            a.item("TotalCount", "Number:double");
        }
        static d(a) {
            WebHeadSelectorTemplateDetailsDescriptionMetadata.b(a);
            a.ac("WebHeadSelectorTemplateDetails", () => new WebHeadSelectorTemplateDetailsDescription());
            a.ab("WebHeadSelectorTemplateDetails", WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
        }
    }
    WebHeadSelectorTemplateDetailsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebHeadSelectorTemplateDetailsDescriptionMetadata, 'WebHeadSelectorTemplateDetailsDescriptionMetadata');
    WebHeadSelectorTemplateDetailsDescriptionMetadata.a = null;
    return WebHeadSelectorTemplateDetailsDescriptionMetadata;
})();
